=== added directory 'bzrlib/store/revision'
=== added file 'bzrlib/store/revision/__init__.py'
--- bzrlib/store/revision/__init__.py	1970-01-01 00:00:00 +0000
+++ bzrlib/store/revision/__init__.py	2006-03-03 01:47:22 +0000
@@ -0,0 +1,66 @@
+# Copyright (C) 2006 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as published by
+# the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Revision stores.
+
+Revision stores are responsible for storing a group of revisions
+and returning some interesting data about them such as ancestors
+and ghosts information.
+"""
+
+
+from copy import deepcopy
+from unittest import TestSuite
+
+
+
+class RevisionStoreTestProviderAdapter(object):
+    """A tool to generate a suite testing multiple repository stores.
+
+    This is done by copying the test once for each repository store
+    and injecting the transport_server, transport_readonly_server,
+    and revision-store-factory into each copy.
+    Each copy is also given a new id() to make it easy to identify.
+    """
+
+    def __init__(self, transport_server, transport_readonly_server, factories):
+        self._transport_server = transport_server
+        self._transport_readonly_server = transport_readonly_server
+        self._factories = factories
+    
+    def adapt(self, test):
+        result = TestSuite()
+        for factory in self._factories:
+            new_test = deepcopy(test)
+            new_test.transport_server = self._transport_server
+            new_test.transport_readonly_server = self._transport_readonly_server
+            new_test.store_factory = factory
+            def make_new_test_id():
+                new_id = "%s(%s)" % (new_test.id(), factory)
+                return lambda: new_id
+            new_test.id = make_new_test_id()
+            result.addTest(new_test)
+        return result
+
+    @staticmethod
+    def default_test_list():
+        """Generate the default list of revision store permutations to test."""
+        from bzrlib.store.revision.text import TextRevisionStoreTestFactory
+        from bzrlib.store.revision.knit import KnitRevisionStoreFactory
+        result = []
+        # test the fallback InterVersionedFile from weave to annotated knits
+        result.append(TextRevisionStoreTestFactory())
+        result.append(KnitRevisionStoreFactory())
+        return result

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2006-03-02 01:26:22 +0000
+++ bzrlib/tests/test_selftest.py	2006-03-03 01:47:22 +0000
@@ -317,7 +317,7 @@
             "test_adapted_tests")
         server1 = "a"
         server2 = "b"
-        formats = [(str, "C1", "C2"), (str, "D1", "D2")]
+        formats = [(str, "C1", "C2"), (int, "D1", "D2")]
         adapter = InterRepositoryTestProviderAdapter(server1, server2, formats)
         suite = adapter.adapt(input_test)
         tests = list(iter(suite))
@@ -327,7 +327,7 @@
         self.assertEqual(tests[0].repository_format_to, formats[0][2])
         self.assertEqual(tests[0].transport_server, server1)
         self.assertEqual(tests[0].transport_readonly_server, server2)
-        self.assertEqual(tests[0].interrepo_class, formats[1][0])
+        self.assertEqual(tests[1].interrepo_class, formats[1][0])
         self.assertEqual(tests[1].repository_format, formats[1][1])
         self.assertEqual(tests[1].repository_format_to, formats[1][2])
         self.assertEqual(tests[1].transport_server, server1)
@@ -345,7 +345,7 @@
             "test_adapted_tests")
         server1 = "a"
         server2 = "b"
-        formats = [(str, "C1", "C2"), (str, "D1", "D2")]
+        formats = [(str, "C1", "C2"), (int, "D1", "D2")]
         adapter = InterVersionedFileTestProviderAdapter(server1, server2, formats)
         suite = adapter.adapt(input_test)
         tests = list(iter(suite))
@@ -355,13 +355,40 @@
         self.assertEqual(tests[0].versionedfile_factory_to, formats[0][2])
         self.assertEqual(tests[0].transport_server, server1)
         self.assertEqual(tests[0].transport_readonly_server, server2)
-        self.assertEqual(tests[0].interversionedfile_class, formats[1][0])
+        self.assertEqual(tests[1].interversionedfile_class, formats[1][0])
         self.assertEqual(tests[1].versionedfile_factory, formats[1][1])
         self.assertEqual(tests[1].versionedfile_factory_to, formats[1][2])
         self.assertEqual(tests[1].transport_server, server1)
         self.assertEqual(tests[1].transport_readonly_server, server2)
 
 
+class TestRevisionStoreProviderAdapter(TestCase):
+    """A group of tests that test the RevisionStore test adapter."""
+
+    def test_adapted_tests(self):
+        # check that constructor parameters are passed through to the adapted
+        # test.
+        from bzrlib.store.revision import RevisionStoreTestProviderAdapter
+        input_test = TestRevisionStoreProviderAdapter(
+            "test_adapted_tests")
+        # revision stores need a store factory - i.e. RevisionKnit
+        #, a readonly and rw transport 
+        # transport servers:
+        server1 = "a"
+        server2 = "b"
+        store_factories = ["c", "d"]
+        adapter = RevisionStoreTestProviderAdapter(server1, server2, store_factories)
+        suite = adapter.adapt(input_test)
+        tests = list(iter(suite))
+        self.assertEqual(2, len(tests))
+        self.assertEqual(tests[0].store_factory, store_factories[0][0])
+        self.assertEqual(tests[0].transport_server, server1)
+        self.assertEqual(tests[0].transport_readonly_server, server2)
+        self.assertEqual(tests[1].store_factory, store_factories[1][0])
+        self.assertEqual(tests[1].transport_server, server1)
+        self.assertEqual(tests[1].transport_readonly_server, server2)
+
+
 class TestWorkingTreeProviderAdapter(TestCase):
     """A group of tests that test the workingtree implementation test adapter."""
 

